import { HttpClient } from '@angular/common/http';
import { Component } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'app-create-pxe-template',
  templateUrl: './create-pxe-template.component.html',
  styleUrl: './create-pxe-template.component.css'
})
export class CreatePxeTemplateComponent {
  firstFormGroup!: FormGroup; // Use `!` to assert that this will be initialized
  secondFormGroup!: FormGroup; // Use `!` to assert that this will be initialized
  previewContent: string = '';

  constructor(
    public dialogRef: MatDialogRef<CreatePxeTemplateComponent>,
    private http: HttpClient,
    private fb: FormBuilder
  ) {}

  ngOnInit() {
    this.firstFormGroup = this.fb.group({
      name: ['', Validators.required]
    });
    this.secondFormGroup = this.fb.group({
      timeout: [0, Validators.required],
      timeoutStyle: ['hidden', Validators.required],
      isoDir: ['OGLIVE', Validators.required],
      kernelArgs: ['INFOHOST', Validators.required]
    });

    this.secondFormGroup.valueChanges.subscribe(() => {
      this.updatePreview();
    });
  }

  updatePreview() {
    const formValues = { ...this.firstFormGroup.value, ...this.secondFormGroup.value };
    this.previewContent = `#!ipxe
set timeout ${formValues.timeout}
set timeout-style ${formValues.timeoutStyle}

set ISODIR ${formValues.isoDir}
set default 0
set kernelargs ${formValues.kernelArgs}
#Menú de entrada para seleccionar OgLive

:try_iso
kernel http://SERVERIP/tftpboot/\${ISODIR}/ogvmlinuz \${kernelargs} || goto fallback
initrd http://SERVERIP/tftpboot/\${ISODIR}/oginitrd.img
boot

:fallback
echo "OgLive default"
set ISODIR ogLive
kernel http://SERVERIP/tftpboot/\${ISODIR}/ogvmlinuz \${kernelargs}
initrd http://SERVERIP/tftpboot/\${ISODIR}/oginitrd.img
boot`;
  }

  onCreate(): void {
    const formValues = { ...this.firstFormGroup.value, ...this.secondFormGroup.value };
    const payload = {
      name: formValues.name,
      templateContent: "this.previewContent"
    };
    console.log(payload)
    this.http.post<any>('http://127.0.0.1:8080/pxe-templates', payload).subscribe({
      next: data => {
        console.log('Plantilla PXE creada:', data);
        this.dialogRef.close(true);
      },
      error: error => {
        console.error('Error al crear la plantilla PXE:', error);
        this.dialogRef.close(false);
      }
    });
  }

  onCancel(): void {
    this.dialogRef.close(false);
  }
}
